pub struct WorkflowInstance {
pub id: String,
pub definition_id: String,
pub version: u32,
pub description: String,
pub reference: String,
pub status: i32,
pub data: Option<Struct>,
pub create_time: Option<Timestamp>,
pub complete_time: Option<Timestamp>,
pub execution_pointers: Vec<ExecutionPointer>,
pub name: String,
}Fields
id: Stringdefinition_id: Stringversion: u32description: Stringreference: Stringstatus: i32data: Option<Struct>create_time: Option<Timestamp>complete_time: Option<Timestamp>execution_pointers: Vec<ExecutionPointer>name: StringHuman-friendly unique name, auto-assigned as {definition_id}-{N} at
start time, or the caller-supplied override from StartWorkflowRequest.
Interchangeable with id in Get/Cancel/Suspend/Resume/Watch/Logs RPCs.
Implementations
Sourceimpl WorkflowInstance
impl WorkflowInstance
Sourcepub fn status(&self) -> WorkflowStatus
pub fn status(&self) -> WorkflowStatus
Returns the enum value of status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: WorkflowStatus)
pub fn set_status(&mut self, value: WorkflowStatus)
Sets status to the provided enum value.